@@ -1,8 +1,8 @@
 use anyhow::Context;
 use once_cell::sync::Lazy;
 use smol::lock::{Semaphore, SemaphoreGuardArc};
-use smol_timeout::TimeoutExt;
-use std::{sync::Arc, time::Duration};
+
+use std::sync::Arc;
 
 // limit the number of fds to a very low number to avoid running out
 #[cfg(target_os = "macos")]
@@ -13,9 +13,5 @@ static FD_SEMAPHORE: Lazy<Arc<Semaphore>> = Lazy::new(|| Arc::new(Semaphore::new
 
 /// Blocks until a file descriptor is free, then acquires a guard.
 pub(crate) async fn acquire_fd() -> anyhow::Result<SemaphoreGuardArc> {
-    FD_SEMAPHORE
-        .acquire_arc()
-        .timeout(Duration::from_millis(300))
-        .await
-        .context("could not acquire")
+    FD_SEMAPHORE.try_acquire_arc().context("could not acquire")
 }
